@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2015 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -41,7 +41,15 @@ abstract class CAbstractScreenImporter extends CImporter {
 					$screenItem['resourceid'] = 0;
 					continue;
 				}
-
+				if ($screenItem['rowspan'] == 0) {
+					$screenItem['rowspan'] = 1;
+				}
+				if ($screenItem['colspan'] == 0) {
+					$screenItem['colspan'] = 1;
+				}
+				if (!isset($screenItem['max_columns'])) {
+					$screenItem['max_columns'] = SCREEN_SURROGATE_MAX_COLUMNS_DEFAULT;
+				}
 				switch ($screenItem['resourcetype']) {
 					case SCREEN_RESOURCE_HOSTS_INFO:
 					case SCREEN_RESOURCE_TRIGGERS_INFO:
@@ -64,17 +72,20 @@ abstract class CAbstractScreenImporter extends CImporter {
 						break;
 
 					case SCREEN_RESOURCE_GRAPH:
-						$dbGraphs = API::Graph()->getObjects($resource);
-						if (empty($dbGraphs)) {
+					case SCREEN_RESOURCE_LLD_GRAPH:
+						$hostId = $this->referencer->resolveHostOrTemplate($resource['host']);
+						$graphId = $this->referencer->resolveGraph($hostId, $resource['name']);
+
+						if (!$graphId) {
 							throw new Exception(_s('Cannot find graph "%1$s" used in screen "%2$s".',
 								$resource['name'], $screen['name']));
 						}
 
-						$tmp = reset($dbGraphs);
-						$screenItem['resourceid'] = $tmp['graphid'];
+						$screenItem['resourceid'] = $graphId;
 						break;
 
 					case SCREEN_RESOURCE_SIMPLE_GRAPH:
+					case SCREEN_RESOURCE_LLD_SIMPLE_GRAPH:
 					case SCREEN_RESOURCE_PLAIN_TEXT:
 						$hostId = $this->referencer->resolveHostOrTemplate($resource['host']);
 						$screenItem['resourceid'] = $this->referencer->resolveItem($hostId, $resource['key']);
@@ -104,7 +115,6 @@ abstract class CAbstractScreenImporter extends CImporter {
 						$screenItem['resourceid'] = 0;
 						break;
 				}
-
 			}
 			unset($screenItem);
 		}
